Hotel Sweeneys - Sydney, NSW - Beer Menu on Untappd
Author: The Untappd Team
Description: See what's currently available on Hotel Sweeneys's beer menu in Sydney, NSW in real-time. See activity, upcoming events, photos and more
Keywords: See what's currently available on Hotel Sweeneys's beer menu in Sydney, NSW in real-time. See activity, upcoming events, photos and more

Verified

# Hotel Sweeneys

## Bar, Roof Deck, Beer Garden, Thai Restaurant

236 Clarence St Sydney, NSW ( Map )

0292671796

Yelp Foursquare https://hotelsweeneys.com.au

Yelp Foursquare

236 Clarence St Sydney, NSW (Map)

0292671796

https://hotelsweeneys.com.au

{"count":7,"items":[{"day_name":"Monday","is_24":0,"is_open":1,"hours":[{"start_time":"10:00:00","end_time":"03:00:00"}]},{"day_name":"Tuesday","is_24":0,"is_open":1,"hours":[{"start_time":"10:00:00","end_time":"03:00:00"}]},{"day_name":"Wednesday","is_24":0,"is_open":1,"hours":[{"start_time":"10:00:00","end_time":"03:00:00"}]},{"day_name":"Thursday","is_24":0,"is_open":1,"hours":[{"start_time":"10:00:00","end_time":"03:00:00"}]},{"day_name":"Friday","is_24":0,"is_open":1,"hours":[{"start_time":"10:00:00","end_time":"03:00:00"}]},{"day_name":"Saturday","is_24":0,"is_open":1,"hours":[{"start_time":"10:00:00","end_time":"03:00:00"}]},{"day_name":"Sunday","is_24":0,"is_open":1,"hours":[{"start_time":"12:00:00","end_time":"22:00:00"}]}]}

### Receive Venue Notifications

Receive alerts via Untappd on your mobile device when this venue adds new beers and/or events!

Choose notifications

An error occured. Please try again.

Great! Your subscription to this venue was successful.

### Unlock a Badge Here

Sweeney's Rooftop

Check in to a beer at this location to unlock an exclusive badge!

### Hours

- Monday

  10AM - 3AM

- Tuesday

  10AM - 3AM

- Wednesday

  10AM - 3AM

- Thursday

  10AM - 3AM

- Friday

  10AM - 3AM

- Saturday

  10AM - 3AM

- Sunday

  12PM - 10PM

### Details

- Payment Types: Cash, American Express, Master Card, Visa
- Food Served
- Kegs
- Nitro
- Cask
- Wine
- Cocktails
- Outdoor Seating
- Child Friendly
- Smoke Friendly

### Social

Yelp Foursquare

### Venue Stats (?)

- 55,987 Total
- 3,218 Unique
- 408 Monthly
- 0 You

### Loyal Patrons (?)

More Venue Details

### Photos

See More Photos

### Recent Activity

- Mon, 03 Mar 2025 04:43:31 +0000

  #### Thiago Depes

  ##### Shredalotl

  ##### Ocean Reach Brewing

- Mon, 03 Mar 2025 04:36:59 +0000

  #### Thiago Depes

  ##### Hyper 8

  ##### Ocean Reach Brewing

- Mon, 03 Mar 2025 04:23:08 +0000

  #### Rangelton

  ##### XB

  ##### Theakston

- Mon, 03 Mar 2025 04:15:04 +0000

  #### Rangelton

  ##### The Fursty Ferret

  ##### Badger Brewery (Hall & Woodhouse)

- Mon, 03 Mar 2025 00:08:16 +0000

  #### Astrid Fischer

  ##### Tropical XPA

  ##### Ocean Reach Brewing

See All Activity

See Latest Activity

### All Menus

Loading...
Show More